@@ -95,49 +95,15 @@ Note:
     you can skip the --neptune_api_token
 
 """
+import warnings
 
-import argparse
-import json
-
-import neptune
-
-
-def main(arguments):
-    with open(arguments.filepath, 'r') as fp:
-        json_exp = json.load(fp)
-
-    neptune.init(api_token=arguments.api_token,
-                 project_qualified_name=arguments.project_name)
-
-    with neptune.create_experiment(name=json_exp['name'],
-                                   description=json_exp['description'],
-                                   params=json_exp['params'],
-                                   properties=json_exp['properties'],
-                                   tags=json_exp['tags'],
-                                   upload_source_files=json_exp['upload_source_files']):
-
-        for name, channel_xy in json_exp['log_metric'].items():
-            for x, y in zip(channel_xy['x'], channel_xy['y']):
-                neptune.log_metric(name, x=x, y=y)
-
-        for name, channel_xy in json_exp['log_text'].items():
-            for x, y in zip(channel_xy['x'], channel_xy['y']):
-                neptune.log_text(name, x=x, y=y)
-
-        for name, channel_xy in json_exp['log_image'].items():
-            for x, y in zip(channel_xy['x'], channel_xy['y']):
-                neptune.log_image(name, x=x, y=y)
-
-        for filename in json_exp['log_artifact']:
-            neptune.log_artifact(filename)
-
-def parse_args():
-    parser = argparse.ArgumentParser()
-    parser.add_argument('-f', '--filepath')
-    parser.add_argument('-t', '--api_token', default=None)
-    parser.add_argument('-p', '--project_name', default=None)
-    return parser.parse_args()
+from neptunecontrib.create_experiment_from_json import main, parse_args
 
+message = """neptunecontrib.logging.chart was moved to neptunecontrib.api.
+You should use ``from neptunecontrib.api import log_chart`` 
+neptunecontrib.logging.log_chart will be removed in future releases.
+"""
+warnings.warn(message)
 
 if __name__ == '__main__':
     args = parse_args()
